@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: adjunctions
 version: 4.3
-id: adjunctions-4.3-05e83bc618f3f68473cfebcb6bdadb51
-key: adjun_HDsJYgzYdktElBtpAiTjFy
+id: adjunctions-4.3-e46cf12f2e7e306822764e6eb775fdd9
+key: adjun_JgKV37RcHRvGDaxmTWmd9D
 license: BSD3
 copyright: Copyright (C) 2011-2014 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -26,18 +26,18 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/adjunctions-4.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/adjunctions-4.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/adjunctions-4.3
-hs-libraries: HSadjunctions-4.3-HDsJYgzYdktElBtpAiTjFy
+hs-libraries: HSadjunctions-4.3-JgKV37RcHRvGDaxmTWmd9D
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    comonad-5-530ea4e1d08a0115920b946124e760ac
+    comonad-5-a91321d086a2de4a04a44d60c347669e
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     contravariant-1.4-7b1149a75def92c79deb23a86e0b36cb
-    distributive-0.5.0.2-17a8848c95a42a5c612669379433d996
-    free-4.12.4-6ceee3b0778288ec7c5c8e8d64937985
+    distributive-0.5.0.2-6c580c91b8bf5de803bfa850eb262f37
+    free-4.12.4-d9a4c0f5afbed93cf1b5cb75cd23ad91
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
-    profunctors-5.2-1b9f80ec12ba976fbd92d616f7b33d0d
-    semigroupoids-5.0.1-fafa53fc1a76ec617ee4419105d11368
+    profunctors-5.2-dcebd670a79351324a9f8d71a72c88e3
+    semigroupoids-5.0.1-d6a1ac9616a3b8232f6b4a54c12a0db0
     semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
     tagged-0.8.3-aa128de4449752177a05765fb0ce3959
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
